pub struct LogWriter { /* private fields */ }Expand description
A log writer that produces zstd-compressed JSONL segment files
in a directory, compatible with LogTailer.
Implementations
Sourceimpl LogWriter
impl LogWriter
Sourcepub fn write_line(&mut self, line: &str) -> Result<()>
pub fn write_line(&mut self, line: &str) -> Result<()>
Write a JSONL line (record) to the current segment.
If no segment is open, one will be created. After writing,
if the segment has exceeded max_file_size or
max_segment_duration it will be closed and a new segment
will be opened on the next write.
Sourcepub fn write_value<S: Serialize>(&mut self, value: &S) -> Result<()>
pub fn write_value<S: Serialize>(&mut self, value: &S) -> Result<()>
Serialize value to JSON and write it as a JSONL line.
Sourcepub fn maintain(&mut self) -> Result<()>
pub fn maintain(&mut self) -> Result<()>
Flush and close the current segment if it has exceeded
max_segment_duration. This is a no-op if no segment is
open or if the duration has not been exceeded.
Sourcepub fn close(&mut self) -> Result<()>
pub fn close(&mut self) -> Result<()>
Flush and close the current segment, regardless of whether it has exceeded any configured constraints.
Sourcepub fn flush_without_marking_done(&mut self) -> Result<()>
pub fn flush_without_marking_done(&mut self) -> Result<()>
Finish the zstd stream so the data is readable, but do NOT mark the file as done (readonly). This is useful for tests that need to simulate an in-progress segment.