pub struct LogWriterConfig {
pub log_dir: Utf8PathBuf,
pub max_file_size: u64,
pub compression_level: i32,
pub max_segment_duration: Option<Duration>,
pub suffix: Option<String>,
pub tz: Option<Tz>,
}Expand description
Configuration for constructing a LogWriter.
Fields
log_dir: Utf8PathBufDirectory where log segment files will be created.
max_file_size: u64Maximum number of uncompressed bytes written per segment before rolling to a new file.
compression_level: i32Zstd compression level.
max_segment_duration: Option<Duration>If set, the segment will be closed after this duration even if max_file_size has not been reached.
suffix: Option<String>Optional suffix appended to segment file names.
tz: Option<Tz>Timezone used when computing the segment file name. Defaults to UTC.
Implementations
Sourceimpl LogWriterConfig
impl LogWriterConfig
pub fn new(log_dir: Utf8PathBuf) -> Self
pub fn max_file_size(self, size: u64) -> Self
pub fn compression_level(self, level: i32) -> Self
pub fn max_segment_duration(self, duration: Duration) -> Self
pub fn suffix(self, suffix: impl Into<String>) -> Self
pub fn tz(self, tz: Tz) -> Self